@@ -14,11 +14,13 @@ setMethod("dwiQball","dtiData",function(object,what="wODF",order=4,lambda=0,mask
   if (!(what %in% c("ODF","wODF","aODF","ADC"))) {
     stop("what should specify either ODF, wODF, aODF, or ADC\n")
   }
+  if(!is.null(attributes(object)$ns0)) object <- expanddwiobj(object)
   ngrad <- object@ngrad
   ddim <- object@ddim
   s0ind <- object@s0ind
   ns0 <- length(s0ind)
   sdcoef <- object@sdcoef
+  if(is.null(mask)) mask <- object@mask
   z <- sioutlier(object@si,s0ind)
   si <- aperm(array(z$si,c(ngrad,ddim)),c(2:4,1))
   index <- z$index
