@@ -12,9 +12,3 @@ double F77_SUB(bessliex)(double *x, double *nu, double *expo, double *bi) {
 double F77_SUB(gammaf)(double *x) {
    return gammafn(*x);
 }
-double F77_SUB(digammaf)(double *x) {
-   return digamma(*x);
-}
-double F77_SUB(lgammaf)(double *x) {
-   return lgammafn(*x);
-}
